@@ -6,7 +6,8 @@ os.environ["PYTORCH_ENABLE_MPS_FALLBACK"] = "1"
 from multiprocessing import Pool
 
 from rl_algo_impls.runner.running_utils import base_parser
-from rl_algo_impls.runner.train import train as runner_train, TrainArgs
+from rl_algo_impls.runner.train import TrainArgs
+from rl_algo_impls.runner.train import train as runner_train
 
 
 def train() -> None:
@@ -32,12 +33,12 @@ def train() -> None:
     parser.add_argument(
         "--virtual-display", action="store_true", help="Use headless virtual display"
     )
-    parser.set_defaults(
-        algo=["a2c"],
-        env=["LunarLander-v2"],
-        seed=[10, 20, 30],
-        pool_size=3,
-    )
+    # parser.set_defaults(
+    #     algo=["ppo"],
+    #     env=["CartPole-v1"],
+    #     seed=[10],
+    #     pool_size=3,
+    # )
     args = parser.parse_args()
     print(args)
 
