@@ -3,8 +3,9 @@ sudo apt install -y python-opengl
 sudo apt install -y ffmpeg
 sudo apt install -y xvfb
 sudo apt install -y swig
+sudo apt install -y default-jdk
 
 python3 -m pip install --upgrade pip
 pip install --upgrade torch torchvision torchaudio
 
-python -m pip install --upgrade '.[test,procgen]'
\ No newline at end of file
+python -m pip install --upgrade '.[all]'
\ No newline at end of file
